env_flag_enabled

Function env_flag_enabled 

pub fn env_flag_enabled(var_name: &str) -> bool
Check an environment variable as a boolean diagnostic flag.

Returns true if the variable is set to "1" or "true" (case-insensitive).