pub struct FallbackWidget { /* private fields */ }Expand description
A standalone fallback widget for rendering error indicators.
Can be used independently of ErrorBoundary when you need to
display an error state in a widget area.
Implementations
Sourceimpl FallbackWidget
impl FallbackWidget
Sourcepub fn new(error: CapturedError) -> Self
pub fn new(error: CapturedError) -> Self
Create a new fallback widget for the given error.
Sourcepub fn from_message(
message: impl Into<String>,
widget_name: &'static str,
) -> Self
pub fn from_message( message: impl Into<String>, widget_name: &'static str, ) -> Self
Create a fallback with a simple message and widget name.
Sourcepub fn without_retry_hint(self) -> Self
pub fn without_retry_hint(self) -> Self
Disable the retry hint.