pub struct FocusIndicator { /* private fields */ }Expand description
Configuration for how focused widgets render their focus cue.
Combines a FocusIndicatorKind (what to draw) with a Style
(how to draw it). Widgets call style to
get the overlay style and kind to decide
the rendering strategy.
Implementations
Sourceimpl FocusIndicator
impl FocusIndicator
Sourcepub fn style_overlay(style: Style) -> Self
pub fn style_overlay(style: Style) -> Self
Create a focus indicator with a custom style overlay.
Sourcepub fn with_style(self, style: Style) -> Self
pub fn with_style(self, style: Style) -> Self
Set the style for this indicator.
Sourcepub fn with_kind(self, kind: FocusIndicatorKind) -> Self
pub fn with_kind(self, kind: FocusIndicatorKind) -> Self
Set the kind of indicator.
Sourcepub fn kind(&self) -> FocusIndicatorKind
pub fn kind(&self) -> FocusIndicatorKind
Get the indicator kind.
Sourcepub fn is_visible(&self) -> bool
pub fn is_visible(&self) -> bool
Check if this indicator has a visible focus cue.