HelpId

Struct HelpId 

pub struct HelpId(pub u64);
Unique identifier for a help-registered widget.

Typically corresponds to a FocusId but is its own type so the help system can be used independently of focus management.

Tuple Fields

0: u64