HistoryPanel

Struct HistoryPanel 

pub struct HistoryPanel { /* private fields */ }
History panel widget that displays undo/redo command history.

The panel shows commands in chronological order with the current position marked. Commands above the marker can be undone, commands below can be redone.

Implementations

Source

impl HistoryPanel

pub fn new() -> Self

Create a new history panel with no entries.

pub fn with_title(self, title: impl Into<String>) -> Self

Set the panel title.

pub fn with_undo_items(self, items: &[impl AsRef<str>]) -> Self

Set the undo items (descriptions from oldest to newest).

pub fn with_redo_items(self, items: &[impl AsRef<str>]) -> Self

Set the redo items (descriptions from oldest to newest).

pub fn with_mode(self, mode: HistoryPanelMode) -> Self

Set the display mode.

pub fn with_compact_limit(self, limit: usize) -> Self

Set the compact mode limit.

pub fn with_title_style(self, style: Style) -> Self

Set the title style.

pub fn with_undo_style(self, style: Style) -> Self

Set the undo items style.

pub fn with_redo_style(self, style: Style) -> Self

Set the redo items style.

pub fn with_marker_style(self, style: Style) -> Self

Set the marker style.

pub fn with_bg_style(self, style: Style) -> Self

Set the background style.

pub fn with_marker_text(self, text: impl Into<String>) -> Self

Set the marker text.

pub fn with_undo_icon(self, icon: impl Into<String>) -> Self

Set the undo icon prefix.

pub fn with_redo_icon(self, icon: impl Into<String>) -> Self

Set the redo icon prefix.

pub fn is_empty(&self) -> bool

Check if there are any history items.

pub fn len(&self) -> usize

Get the total number of items.

pub fn undo_items(&self) -> &[String]

Get the undo stack items.

pub fn redo_items(&self) -> &[String]

Get the redo stack items.