List

Struct List 

pub struct List<'a> { /* private fields */ }
A widget to display a list of items.

Implementations

Source

impl<'a> List<'a>

pub fn new(items: impl IntoIterator<Item = impl Into<ListItem<'a>>>) -> Self

Create a new list from the given items.

pub fn block(self, block: Block<'a>) -> Self

Wrap the list in a decorative block.

pub fn style(self, style: Style) -> Self

Set the base style for the list area.

pub fn highlight_style(self, style: Style) -> Self

Set the style applied to the selected item.

pub fn hover_style(self, style: Style) -> Self

Set the style applied to the hovered item (mouse move).

pub fn highlight_symbol(self, symbol: &'a str) -> Self

Set a symbol displayed before the selected item.

pub fn hit_id(self, id: HitId) -> Self

Set a hit ID for mouse interaction.

When set, each list item will register a hit region with the frame’s hit grid (if enabled). The hit data will be the item’s index, allowing click handlers to determine which item was clicked.