pub struct Padding<W> { /* private fields */ }Expand description
A widget wrapper that applies padding around an inner widget.
Implementations
Sourceimpl<W> Padding<W>
impl<W> Padding<W>
Sourcepub const fn padding_sides(&self) -> Sides
pub const fn padding_sides(&self) -> Sides
Get the configured padding.
Sourcepub fn inner_area(&self, area: Rect) -> Rect
pub fn inner_area(&self, area: Rect) -> Rect
Compute the inner rect for a given outer area.
Sourcepub fn into_inner(self) -> W
pub fn into_inner(self) -> W
Consume and return the inner widget.