pub struct Paragraph<'a> { /* private fields */ }Expand description
A widget that renders multi-line styled text.
Implementations
Sourceimpl<'a> Paragraph<'a>
impl<'a> Paragraph<'a>
Sourcepub fn new<'t>(text: impl Into<FtuiText<'t>>) -> Self
pub fn new<'t>(text: impl Into<FtuiText<'t>>) -> Self
Create a new paragraph from the given text.
Sourcepub fn from_static_text(text: FtuiText<'static>) -> Self
pub fn from_static_text(text: FtuiText<'static>) -> Self
Create a new paragraph from text that is already valid for the widget’s storage lifetime.
Sourcepub fn from_static_str(text: &'static str) -> Self
pub fn from_static_str(text: &'static str) -> Self
Create a new paragraph from a static string without copying the string contents.