pub enum Placement {
Above,
Below,
Left,
Right,
AboveCentered,
BelowCentered,
}Expand description
Where to place the popover relative to the anchor.
Variants
Above
Above the anchor, horizontally aligned to its left edge.
Below
Below the anchor, horizontally aligned to its left edge.
Left
To the left of the anchor, vertically aligned to its top edge.
Right
To the right of the anchor, vertically aligned to its top edge.
AboveCentered
Above the anchor, horizontally centered.
BelowCentered
Below the anchor, horizontally centered.