pub struct Stopwatch<'a> { /* private fields */ }Expand description
A widget that displays elapsed time from a StopwatchState.
Implementations
Sourceimpl<'a> Stopwatch<'a>
impl<'a> Stopwatch<'a>
Sourcepub fn format(self, format: StopwatchFormat) -> Self
pub fn format(self, format: StopwatchFormat) -> Self
Sets the display format.
Sourcepub fn running_style(self, style: Style) -> Self
pub fn running_style(self, style: Style) -> Self
Sets a style override used when the stopwatch is running.
Sourcepub fn stopped_style(self, style: Style) -> Self
pub fn stopped_style(self, style: Style) -> Self
Sets a style override used when the stopwatch is stopped.