pub struct Row { /* private fields */ }Expand description
A row in a table.
Implementations
Sourceimpl Row
impl Row
Sourcepub fn new<'a>(cells: impl IntoIterator<Item = impl Into<Text<'a>>>) -> Self
pub fn new<'a>(cells: impl IntoIterator<Item = impl Into<Text<'a>>>) -> Self
Create a new row from an iterator of cell contents.
Sourcepub fn height(self, height: u16) -> Self
pub fn height(self, height: u16) -> Self
Set the row height in lines.
Values below 1 clamp to a single visible line so rows always consume vertical space deterministically.
Sourcepub fn bottom_margin(self, margin: u16) -> Self
pub fn bottom_margin(self, margin: u16) -> Self
Set the bottom margin after this row.