pub struct Timer<'a> { /* private fields */ }Expand description
A widget that displays remaining time from a TimerState.
Implementations
Sourceimpl<'a> Timer<'a>
impl<'a> Timer<'a>
Sourcepub fn format(self, format: TimerFormat) -> Self
pub fn format(self, format: TimerFormat) -> Self
Sets the display format.
Sourcepub fn running_style(self, style: Style) -> Self
pub fn running_style(self, style: Style) -> Self
Sets a style override used while the timer is running.
Sourcepub fn finished_style(self, style: Style) -> Self
pub fn finished_style(self, style: Style) -> Self
Sets a style override used when the timer has finished.