pub struct ValidationErrorDisplay { /* private fields */ }Expand description
A widget for displaying inline validation errors.
Renders an error message with an icon, styled for visibility and accessibility. Supports smooth appearance/disappearance animations.
Implementations
Sourceimpl ValidationErrorDisplay
impl ValidationErrorDisplay
Sourcepub fn new(message: impl Into<String>) -> Self
pub fn new(message: impl Into<String>) -> Self
Create a new validation error display with the given message.
Sourcepub fn with_code(error_code: &'static str, message: impl Into<String>) -> Self
pub fn with_code(error_code: &'static str, message: impl Into<String>) -> Self
Create from an error code and message.
Sourcepub fn with_style(self, style: Style) -> Self
pub fn with_style(self, style: Style) -> Self
Set the error text style.
Sourcepub fn with_icon_style(self, style: Style) -> Self
pub fn with_icon_style(self, style: Style) -> Self
Set the icon style.
Sourcepub fn with_animation_duration(self, duration: Duration) -> Self
pub fn with_animation_duration(self, duration: Duration) -> Self
Set the animation duration.
Sourcepub fn error_code(&self) -> Option<&'static str>
pub fn error_code(&self) -> Option<&'static str>
Get the error code, if any.