pub struct Table<'a> { /* private fields */ }Expand description
A widget to display data in a table.
Implementations
Sourceimpl<'a> Table<'a>
impl<'a> Table<'a>
Sourcepub fn new(
rows: impl IntoIterator<Item = Row>,
widths: impl IntoIterator<Item = Constraint>,
) -> Self
pub fn new( rows: impl IntoIterator<Item = Row>, widths: impl IntoIterator<Item = Constraint>, ) -> Self
Create a new table with the given rows and column width constraints.
Sourcepub fn data_hash(self, hash: u64) -> Self
pub fn data_hash(self, hash: u64) -> Self
Set an explicit data hash to enable caching of filtered and sorted indices.
This is highly recommended for large tables. When provided, the table widget
will cache the result of filtering and sorting in the TableState, skipping
expensive O(N) re-evaluation on frames where the hash, filter, and sort
parameters have not changed.
Sourcepub fn highlight_style(self, style: Style) -> Self
pub fn highlight_style(self, style: Style) -> Self
Set the style for the selected row.
Sourcepub fn theme(self, theme: TableTheme) -> Self
pub fn theme(self, theme: TableTheme) -> Self
Set the table theme (base/states/effects).
Sourcepub fn theme_phase(self, phase: f32) -> Self
pub fn theme_phase(self, phase: f32) -> Self
Set the explicit animation phase for theme effects.
Phase is deterministic and should be supplied by the caller (e.g. from tick count).
Sourcepub fn column_spacing(self, spacing: u16) -> Self
pub fn column_spacing(self, spacing: u16) -> Self
Set the spacing between columns.