pub struct TableState {
pub selected: Option<usize>,
pub hovered: Option<usize>,
pub offset: usize,
/* private fields */
}Expand description
Mutable state for a Table widget.
Fields
selected: Option<usize>Index of the currently selected row, if any.
hovered: Option<usize>Index of the currently hovered row, if any.
offset: usizeScroll offset (first visible row index).
Implementations
Sourceimpl TableState
impl TableState
Sourcepub fn select(&mut self, index: Option<usize>)
pub fn select(&mut self, index: Option<usize>)
Set the selected row index, resetting offset on deselect.
Sourcepub fn with_persistence_id(self, id: impl Into<String>) -> Self
pub fn with_persistence_id(self, id: impl Into<String>) -> Self
Create a new TableState with a persistence ID for state saving.
Sourcepub fn persistence_id(&self) -> Option<&str>
pub fn persistence_id(&self) -> Option<&str>
Get the persistence ID, if set.
Sourceimpl TableState
impl TableState
Sourcepub fn undo_id(&self) -> UndoWidgetId
pub fn undo_id(&self) -> UndoWidgetId
Get the undo widget ID.
This can be used to associate undo commands with this state instance.
Sourcepub fn sort_column(&self) -> Option<usize>
pub fn sort_column(&self) -> Option<usize>
Get the current sort column.
Sourcepub fn sort_ascending(&self) -> bool
pub fn sort_ascending(&self) -> bool
Get whether the sort is ascending.
Sourcepub fn set_filter(&mut self, filter: impl Into<String>)
pub fn set_filter(&mut self, filter: impl Into<String>)
Set the filter text.