pub struct VirtualizedList<'a, T> { /* private fields */ }Expand description
A virtualized list widget that renders only visible items.
This widget efficiently renders large lists by only drawing items that are currently visible in the viewport, with optional overscan for smooth scrolling.
Implementations
Sourceimpl<'a, T> VirtualizedList<'a, T>
impl<'a, T> VirtualizedList<'a, T>
Sourcepub fn highlight_style(self, style: Style) -> Self
pub fn highlight_style(self, style: Style) -> Self
Set highlight style for selected item.
Sourcepub fn show_scrollbar(self, show: bool) -> Self
pub fn show_scrollbar(self, show: bool) -> Self
Enable/disable scrollbar.
Sourcepub fn fixed_height(self, height: u16) -> Self
pub fn fixed_height(self, height: u16) -> Self
Set fixed item height.